@@ -10,7 +10,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: edit.c,v 1.41 1995/01/21 01:34:56 mrg Exp $";
+static	char	rcsid[] = "@(#)$Id: edit.c,v 1.43 1995/03/19 03:25:05 mrg Exp $";
 #endif
 
 #include "irc.h"
@@ -682,7 +682,7 @@ sleepcmd(command, args, subargs)
  * processes the flags first, then displays the text on
  * the screen
  */
-void
+static void
 echo(command, args, subargs)
 	char	*command,
 		*args,
@@ -923,7 +923,7 @@ e_channel(command, args, subargs)
 		{
 			if (is_on_channel(chan, get_server_nickname(from_server)))
 			{
-				if (is_bound(chan))
+				if (is_bound(chan, curr_scr_win->server))
 				{
 					say("Channel %s is bound", chan);
 				}
@@ -943,7 +943,7 @@ e_channel(command, args, subargs)
 						send_to_server("PART %s", old);
 				}
 				send_to_server("%s %s %s", command, chan, args);
-				if (!is_bound(chan))
+				if (!is_bound(chan, curr_scr_win->server))
 					malloc_strcpy(&curr_scr_win->waiting_channel, chan);
 			}
 		}
@@ -986,6 +986,8 @@ e_nick(command, args, subargs)
 	if ((nick = check_nickname(nick)) != NULL)
 	{
 		send_to_server("NICK %s", nick);
+		if (attempting_to_connect)
+			set_server_nickname(get_window_server(0),nick);
 		if (get_server_version(from_server) == Server2_5)
 			add_to_whois_queue(nick, whois_nickname,
 				NULL);
@@ -1036,7 +1038,7 @@ info(command, args, subargs)
 		say("major 2.6 helpers:");
 		say("       \tNicolas Pioch        <poich@poly.polytechnique.fr>");
 		say("       \tIan Frechette        <frechett@spot.colorado.edu>");
-		say("       \tChris Williams       <cgw@unt.edu>");
+		say("       \tChris Williams       <cgw@io.com>");
 		say("       \tJeff Grills          <jefftep@cs.utexas.edu>");
 		say("");
 		say("ircii contributors");
@@ -1960,7 +1962,7 @@ send_text(org_nick, line, command)
 	new_free(&free_nick);
 }
 
-void
+static void
 do_send_text(command, args, subargs)
 	char	*command,
 		*args,
