@@ -11,7 +11,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: names.c,v 1.22 1995/01/02 07:32:23 mrg stable $";
+static	char	rcsid[] = "@(#)$Id: names.c,v 1.24 1995/04/05 14:26:13 mrg Exp $";
 #endif
 
 #include "irc.h"
@@ -248,10 +248,11 @@ recreate_mode(chan)
 
 	/* first check if cached string value is ok */
 
-	if (chan->mode == chan->i_mode)
+	if (chan->mode == chan->i_mode && chan->limit == chan->i_limit)
 		return (chan->s_mode);
 
 	chan->i_mode = chan->mode;
+	chan->i_limit = chan->limit;
 	buffer[0] = '\0';
 	mode = chan->mode;
 	while (mode)
@@ -410,7 +411,9 @@ set_channel_mode(channel, mode)
 		tmp->mode = 0;
 		if ((limit = decifer_mode(mode, &(tmp->mode), &(tmp->chop),
 		    &(tmp->nicks), &(tmp->key))) != -1)
+		{
 			tmp->limit = limit;
+		}
 	}
 }
 
@@ -439,13 +442,14 @@ update_channel_mode(channel, mode)
  * channels mode.  Useful for testing a channels mode 
  */
 int
-is_channel_mode(channel, mode)
+is_channel_mode(channel, mode, server_index)
 	char	*channel;
 	int	mode;
+	int	server_index;
 {
 	ChannelList *tmp;
 
-	if ((tmp = lookup_channel(channel, from_server, 0)) != NULL)
+	if ((tmp = lookup_channel(channel, server_index, 0)) != NULL)
 		return (tmp->mode & mode);
 	return 0;
 }
@@ -610,9 +614,9 @@ show_channel(chan)
 	char	*nicks = NULL;
 	char	*s;
 
+	s = recreate_mode(chan);
 	*buffer = (char) 0;
 	buffer_len = 0;
-	s = recreate_mode(chan);
 	for (tmp = chan->nicks; tmp; tmp = tmp->next)
 	{
 		len = strlen(tmp->nick);
@@ -785,7 +789,8 @@ reconnect_all_channels()
 			char	*t;
 
 			s = recreate_mode(tmp);
-			if ((t = tmp->window->current_channel) && *t && !is_bound(t))
+			if ((t = tmp->window->current_channel) && *t
+			&& !is_bound(t, tmp->window->server))
 				malloc_strcpy(&tmp->window->waiting_channel, t);
 			if (get_server_version(from_server) >= Server2_8)
 			{
