@@ -11,7 +11,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: numbers.c,v 1.16 1994/12/18 12:00:35 mrg stable $";
+static	char	rcsid[] = "@(#)$Id: numbers.c,v 1.17 1995/03/19 03:33:05 mrg Exp $";
 #endif
 
 #include "irc.h"
@@ -132,10 +132,13 @@ get_password()
 
 	say("password required for connection to server %s",
 		get_server_name(from_server));
-	sprintf(server_num, "%d", from_server);
 	close_server(from_server, empty_string);
-	add_wait_prompt("Server Password:", password_sendline,
-		server_num, WAIT_PROMPT_LINE);
+        if (!dumb)
+	{
+		sprintf(server_num, "%d", from_server);
+		add_wait_prompt("Server Password:", password_sendline,
+			server_num, WAIT_PROMPT_LINE);
+	}
 }
 
 /*ARGSUSED*/
@@ -149,7 +152,6 @@ nickname_sendline(data, nick)
 	new_server = atoi(data);
 	if ((nick = check_nickname(nick)) != NULL)
 	{
-
 		server = from_server;
 		from_server = new_server;
 		send_to_server("NICK %s", nick);
@@ -163,8 +165,9 @@ nickname_sendline(data, nick)
 	else
 	{
 		say("illegal nickname, try again");
-		add_wait_prompt("Nickname: ", nickname_sendline, data,
-				WAIT_PROMPT_LINE);
+		if (!dumb)
+			add_wait_prompt("Nickname: ", nickname_sendline, data,
+					WAIT_PROMPT_LINE);
 	}
 }
 
@@ -179,12 +182,15 @@ reset_nickname()
 
 	if (already_doing_reset_nickname)
 		return;
-	already_doing_reset_nickname = 1;
 	say("You have specified an illegal nickname");
-	say("Please enter your nickname");
-	sprintf(server_num, "%d", from_server);
-	add_wait_prompt("Nickname: ", nickname_sendline, server_num,
-		WAIT_PROMPT_LINE);
+	if (!dumb)
+	{
+		already_doing_reset_nickname = 1;
+		say("Please enter your nickname");
+		sprintf(server_num, "%d", from_server);
+		add_wait_prompt("Nickname: ", nickname_sendline, server_num,
+			WAIT_PROMPT_LINE);
+	}
 	update_all_status();
 }
 
@@ -564,12 +570,18 @@ numbered_command(from, comm, ArgList)
 		break;
 
 	case 465:		/* #define ERR_YOUREBANNEDCREEP 465 */
-		PasteArgs(ArgList, 0);
-		if (do_hook(current_numeric, "%s %s", from, ArgList[0]))
-			display_msg(from, ArgList);
-		close_server(from_server, empty_string);
-		window_check_servers();
-		break;
+		{
+			int	klined_server = from_server;
+
+			PasteArgs(ArgList, 0);
+			if (do_hook(current_numeric, "%s %s", from, ArgList[0]))
+				display_msg(from, ArgList);
+			close_server(from_server, empty_string);
+			if (server_list_size() > 1)
+				remove_from_server_list(klined_server);
+			window_check_servers();
+			break;
+		}
 
 		/*
 		 * The following accumulates the remaining arguments
