@@ -9,7 +9,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: status.c,v 1.18 1995/01/02 07:32:34 mrg stable $";
+static	char	rcsid[] = "@(#)$Id: status.c,v 1.19 1995/03/19 03:31:48 mrg Exp $";
 #endif
 
 #include "irc.h"
@@ -932,7 +932,8 @@ status_channel(window)
 	{
 		if (get_int_var(HIDE_PRIVATE_CHANNELS_VAR) &&
 		    is_channel_mode(window->current_channel,
-				MODE_PRIVATE | MODE_SECRET))
+				MODE_PRIVATE | MODE_SECRET,
+				window->server))
 			ptr = "*private*";
 		else
 			ptr = window->current_channel;
