@@ -10,7 +10,7 @@
  */
 
 #ifndef lint
-static	char	rcsid[] = "@(#)$Id: window.c,v 1.24 1995/01/10 12:39:14 mrg stable $";
+static	char	rcsid[] = "@(#)$Id: window.c,v 1.25 1995/03/19 03:32:42 mrg Exp $";
 #endif
 
 #include "irc.h"
@@ -1170,8 +1170,10 @@ window_check_servers()
 				if (not_connected)
 					tmp->server = primary_server;
 				else
+				{
 					prime = tmp->server;
-				cnt++;
+					cnt++;
+				}
 			}
 		}
 		if (cnt == 0)
@@ -1180,7 +1182,13 @@ window_check_servers()
 			connected_to_server++;
 	}
 	if (!is_server_open(primary_server))
+	{
+		flag = 1;
+		while ((tmp = traverse_all_windows(&flag)) != NULL)
+			if (tmp->server == primary_server)
+				tmp->server = prime;
 		primary_server = prime;
+	}
 	update_all_status();
 	cursor_to_input();
 }
@@ -1416,27 +1424,31 @@ is_current_channel(channel, delete)
 }
 
 extern int
-is_bound(channel)
+is_bound(channel, server)
 	char	*channel;
+	int	server;
 {
 	Window *tmp;
 	int	flag = 1;
 
 	while (tmp = traverse_all_windows(&flag))
-		if (tmp->bind_channel && !my_stricmp(tmp->bind_channel, channel))
+		if (tmp->server == server && tmp->bind_channel
+		&& !my_stricmp(tmp->bind_channel, channel))
 			return 1;
 	return 0;
 }
 
 extern void
-unbind_channel(channel)
+unbind_channel(channel, server)
 	char	*channel;
+	int	server;
 {
 	Window *tmp;
 	int	flag = 1;
 
 	while (tmp = traverse_all_windows(&flag))
-		if (tmp->bind_channel && !my_stricmp(tmp->bind_channel, channel))
+		if (tmp->server == server && tmp->bind_channel
+		&& !my_stricmp(tmp->bind_channel, channel))
 		{
 			new_free(&tmp->bind_channel);
 			return;
@@ -2351,7 +2363,11 @@ window(command, args, subargs)
 
 				parse_server_info(arg, &port, &password, &nick);
 				if (port)
+				{
 					port_num = atoi(port);
+					if (!port_num)
+						port_num = -1;
+				}
 				else
 					port_num = -1;
 				if ((i = find_in_server_list(arg, port_num))
@@ -2371,9 +2387,9 @@ window(command, args, subargs)
 #else
 					    window->window_level = LOG_NONE;
 #endif
-					    clear_channel_list(from_server);
 					    if (window->current_channel)
 					      new_free(&window->current_channel);
+					    update_all_status();
 					}
 				}
 				else
@@ -2394,6 +2410,7 @@ window(command, args, subargs)
 #endif
 					    if (window->current_channel)
 					      new_free(&window->current_channel);
+					    update_all_status();
 					}
 				}
 			}
@@ -2422,7 +2439,7 @@ window(command, args, subargs)
 		{
 			if ((arg = next_arg(args, &args)) != NULL)
 			{
-				if (is_bound(arg))
+				if (is_bound(arg, from_server))
 				{
 					say("Channel %s is bound", arg);
 				}
@@ -2532,8 +2549,9 @@ window(command, args, subargs)
 					say("BIND: %s is not a valid channel name", arg);
 				else
 				{
-					if (is_bound(arg) && is_current_channel(arg, 1))
-						unbind_channel(arg);
+					if (is_bound(arg, from_server)
+					&& is_current_channel(arg, 1))
+						unbind_channel(arg, from_server);
 					malloc_strcpy(&window->bind_channel, arg);
 					if (is_on_channel(arg, nickname))
 						set_channel_by_refnum(0, arg);
@@ -2547,10 +2565,10 @@ window(command, args, subargs)
 		{
 			if ((arg = next_arg(args, &args)) != (char *) 0)
 			{
-				if (is_bound(arg))
+				if (is_bound(arg, from_server))
 				{
 					say("Channel %s is no longer bound", arg);
-					unbind_channel(arg);
+					unbind_channel(arg, from_server);
 				}
 				else
 					say("Channel %s is not bound", arg);
